@@ -216,11 +216,7 @@ CacheDatabase::getLogLevel()
         settings->setValue ("LogLevel", 2);
     }
 
-#ifdef QGV_DEBUG
-    return 5;
-#else
     return settings->value("LogLevel").toInt ();
-#endif
 }//CacheDatabase::getLogLevel
 
 ContactsModel *
